@@ -24,6 +24,8 @@ from mindfoundry.client.horizon.models.config import (
 
 from .base import FlexibleInputData, HorizonModel, ReportingCallback, ReportingFacility
 
+SeriesOrArray = Union[pd.Series, np.ndarray]
+
 
 @dataclass
 class ClassifierConfig(ModelConfig):
@@ -220,7 +222,7 @@ class HorizonClassifier(HorizonModel):
     def fit(
         self,
         x: FlexibleInputData,
-        y: Union[pd.Series, np.ndarray],
+        y: SeriesOrArray,
         reporting_callback: Optional[ReportingCallback] = None,
     ) -> None:
         """
@@ -335,7 +337,7 @@ class HorizonClassifier(HorizonModel):
     def update(
         self,
         new_x: FlexibleInputData,
-        new_y: Union[pd.Series, np.ndarray],
+        new_y: SeriesOrArray,
         reporting_callback: Optional[ReportingCallback] = None,
     ) -> None:
         """
@@ -419,16 +421,14 @@ class HorizonClassifier(HorizonModel):
         )
 
     def _make_combined_data_frame(
-        self, x: FlexibleInputData, y: Union[pd.Series, np.ndarray]
+        self, x: FlexibleInputData, y: SeriesOrArray
     ) -> Tuple[pd.DataFrame, str]:
-        training_data = self._make_input_data_frame(x)
+        training_data = self._make_input_data_frame(x).copy()  # Don't mutate the original X!
         target_name = self._find_name_for_target_column(training_data, y)
         training_data[target_name] = y
         return training_data, target_name
 
-    def _find_name_for_target_column(
-        self, training_data: pd.DataFrame, y: Union[pd.Series, np.ndarray]
-    ) -> str:
+    def _find_name_for_target_column(self, training_data: pd.DataFrame, y: SeriesOrArray) -> str:
         if self.config.target:
             return self.config.target
 
